@@ -133,7 +133,7 @@ ma3x3.spottedarray <- function(x,printer,FUN=mean,na.rm=TRUE,...)
 fit.normexp <- function(foreground,background=NULL,background.matrix=NULL,trace=0,beta.start=NULL) {
 #	Fit background=normal + signal=exponential model.
 #	Gordon Smyth
-#	24 Aug 2002.  Last modified 19 Nov 2004.
+#	24 Aug 2002.  Last modified 15 Dec 2004.
 
 	f <- foreground
 
@@ -154,7 +154,7 @@ fit.normexp <- function(foreground,background=NULL,background.matrix=NULL,trace=
 		}
 	}
 	sigma <- sqrt(mean((f[f<mu]-mu)^2,na.rm=TRUE))
-	if(!is.infinite(sigma) || sigma < 1) sigma <- 1
+	if(!is.finite(sigma) || sigma < 1) sigma <- 1
 	alpha <- mean(f,na.rm=TRUE) - mu
 	theta <- c(beta,log(sigma),log(alpha))
 	
